# Basic Usage

The following notebooks demonstrate how to construct a basic model for a single annotation task:
* [Model with Scikit-learn](Model-Sklearn.ipynb) - This notebook demonstrates how to construct a model using the [scikit-learn](https://scikit-learn.org/stable/) library.
* [Model with SpaCy](Model-SpaCy.ipynb) - This notebook demonstrates how to construct a model using the [SpaCy](https://spacy.io/) library.
* [Model with Sentence-Transformers](Model-SentenceTransformers.ipynb) - This notebook demonstrates how to construct a model using the [Sentence-Transformers](https://www.sbert.net/) library.
* [Model with Saved Dictionary](Model-SavedDictionary.ipynb) - This notebook demonstrates how to construct a model using vectors from a saved dictionary. This can be useful if you have a large number of annotations and want to save time by not having to recompute the vectors for each annotation.